print-python
============

Print Python Client

Installation:
```bash
$ pipenv install print-python
```

Usage:
```python
>>> import print
>>> print = print.Print('https://<your_print_instance>/<path>')
>>> print.post('As easy as rolling off a log')
```
